==> 0.0.3+7.tar.gz: zhiying_comm/lib/util/global_config.dart <==
class GlobalConfig {
  /// ======================   后端json返回的key   ====================== ///
  static final String HTTP_RESPONSE_KEY_CODE = 'code';
  static final String HTTP_RESPONSE_KEY_MSG = 'msg';
  static final String HTTP_RESPONSE_KEY_DATA = 'data';

  /// 成功返回的CODE值
  static final int RESPONSE_SUCCESS_CODE = 1;

  /// 通用标志key
  static final String SKIP_IDENTIFIER = 'skip_identifier';

  /// ======================   第三方登录key   ====================== ///
  static const String LOGIN_THIRD_ALI = 'taobao'; // 淘宝登录
  static const String LOGIN_THIRD_WECHAT = 'wechat'; // 微信
  static const String LOGIN_THIRD_QQ = 'qq'; // QQ
  static const String LOGIN_THIRD_APPLE = 'apple'; // 苹果登录

  /// ======================   各个渠道的key   ====================== ///
  static const String PROVIDER_TB = 'taobao'; // 淘宝
  static const String PROVIDER_TM = 'tianmao'; // 天猫
  static const String PROVIDER_JD = 'jd'; // 京东
  static const String PROVIDER_KL = 'kaola'; // 考拉
  static const String PROVIDER_VIP = 'vip'; // 唯品会
  static const String PROVIDER_SN = 'suning'; // 苏宁
  static const String PROVIDER_PDD = 'pdd'; // 拼多多

  /// ======================   Shared_prefe_key   ====================== ///
  /// 用户token
  static final String SHARED_KEY_TOKEN = 'sp_token';

  /// 用户手机号码
  static final String SHARED_KEY_MOBILE = 'sp_mobile';

  /// 用户的淘宝授权key
  static final String SHARED_KEY_ISAUTH = 'sp_auth';

  /// 用户json
  static final String SHARED_KEY_USER_INFO = 'sp_userinfo';

  /// 货币类型
  static final String MONEY_TYPE = "¥ ";

  /// 苹果审核
  static final String IS_IOS_REVIEW = 'is_ios_review';

  ///主要配置
  static final String MAIN_CONFIG='sp_main_config';

  ///guide缓存表记
  static final String GUIDE='sp_guide';

}

==> 0.0.12+4.tar.gz: zhiying_comm/lib/util/global_config.dart <==
class GlobalConfig {
  /// ======================   后端json返回的key   ====================== ///
  static final String HTTP_RESPONSE_KEY_CODE = 'code';
  static final String HTTP_RESPONSE_KEY_MSG = 'msg';
  static final String HTTP_RESPONSE_KEY_DATA = 'data';

  /// 成功返回的CODE值
  static final int RESPONSE_SUCCESS_CODE = 1;

  /// 通用标志key
  static final String SKIP_IDENTIFIER = 'skip_identifier';

  /// ======================   第三方登录key   ====================== ///
  static const String LOGIN_THIRD_ALI = 'taobao'; // 淘宝登录
  static const String LOGIN_THIRD_WECHAT = 'wechat'; // 微信
  static const String LOGIN_THIRD_QQ = 'qq'; // QQ
  static const String LOGIN_THIRD_APPLE = 'apple'; // 苹果登录

  /// ======================   各个渠道的key   ====================== ///
  static const String PROVIDER_TB = 'taobao'; // 淘宝
  static const String PROVIDER_TM = 'tmall'; // 天猫tianmao
  static const String PROVIDER_JD = 'jd'; // 京东
  static const String PROVIDER_KL = 'kaola'; // 考拉
  static const String PROVIDER_VIP = 'vip'; // 唯品会
  static const String PROVIDER_SN = 'suning'; // 苏宁
  static const String PROVIDER_PDD = 'pdd'; // 拼多多

  /// ======================   Shared_prefe_key   ====================== ///
  /// 用户token
  static final String SHARED_KEY_TOKEN = 'sp_token';

  /// 用户手机号码
  static final String SHARED_KEY_MOBILE = 'sp_mobile';

  /// 用户的淘宝授权key
  static final String SHARED_KEY_ISAUTH = 'sp_auth';

  /// 用户json
  static final String SHARED_KEY_USER_INFO = 'sp_userinfo';

  /// 货币类型
  static final String MONEY_TYPE = "¥ ";

  /// 苹果审核
  static final String IS_IOS_REVIEW = 'is_ios_review';

  ///主要配置
  static final String MAIN_CONFIG='sp_main_config';

  ///guide缓存表记
  static final String GUIDE='sp_guide';

}
